.. _capi-property:

Function manipulating ``CHFL_PROPERTY``
---------------------------------------

.. doxygentypedef:: CHFL_PROPERTY

.. doxygenfunction:: chfl_property_bool

.. doxygenfunction:: chfl_property_double

.. doxygenfunction:: chfl_property_string

.. doxygenfunction:: chfl_property_vector3d

.. doxygenfunction:: chfl_property_get_kind

.. doxygenfunction:: chfl_property_get_bool

.. doxygenfunction:: chfl_property_get_double

.. doxygenfunction:: chfl_property_get_string

.. doxygenfunction:: chfl_property_get_vector3d

.. doxygenfunction:: chfl_property_free
